# clinicore: A clinical schema

This schema focuses on key clinical data concepts, including patients, treatments, biosamples, and clinical trials with associated artifacts.
In contrast, the related [OMOP](https://github.com/laminlabs/omop) schema is based on the OMOP Common Data Model, which standardizes patient-level observational data.

## Contributing

Please run `pre-commit install` and `gitmoji -i` on the CLI before starting to work on this repository!
